@@ -214,7 +214,7 @@ def columnWrite(*cols):
             # если это последний параметр, и для него не указана ширина
             if q == len(cols)-1:
                 # выводим его полностью не смотря на ширину окна
-                print cols[q],
+                print cols[q].encode('utf8'),
                 cols[q] = ''
             else:
                 # вывести часть строки не больше указанной ширины колонки
